# Changelog

## 16.0.3 - 2025-01-14

- Fix RegEx pattern ([#5](https://github.com/mlodewijck/pyuegc/issues/5#issue-2784939766)).

## 16.0.2 - 2025-01-12

- Fix issue related to regional indicator symbols ([#4](https://github.com/mlodewijck/pyuegc/issues/4#issue-2782298629)).

## 16.0.1 - 2025-01-05

- Fix issue with data needed in regex pattern object used to match certain conjunct linker clusters.
- Drop support for Python versions earlier than 3.8 (due to incompatibilities with the latest versions of pip and its dependencies).
- Return an empty list for `EGC("")` instead of raising a ValueError ([#3](https://github.com/mlodewijck/pyuegc/issues/3#issue-2532566290)).
- Add `CHANGELOG.md` file.

## 16.0.0 - 2024-09-17

- Upgrade to Unicode 16.0.0.

## 15.1.0 - 2023-11-11

- Upgrade to Unicode 15.1.0.

## 15.0.0 - 2022-10-01

- Upgrade to Unicode 15.0.0.

## 14.0.0 - 2021-10-17

_First release._
